@@ -5,14 +5,13 @@
 This is the tuxsuite module.
 """
 
-__version__ = "0.50.2"
+__version__ = "1.0.0"
 
 
 from . import build
 from . import config
 from . import schema, exceptions
 import logging
-import click
 from abc import ABC, abstractmethod
 
 
@@ -158,7 +157,7 @@ class BuildPlan(PlanType):
                 plan_config.plan.append({"build": None, "tests": tests})
 
     def plan_info(self, name, description):
-        click.echo("Running Linux Kernel plan '{}': '{}'".format(name, description))
+        print("Running Linux Kernel plan '{}': '{}'".format(name, description))
 
     def create_builds(self, plan, builds):
         for cfg in plan.config.plan:
@@ -211,7 +210,7 @@ class BakePlan(PlanType):
                     plan_config.plan.append({"build": build_item, "tests": []})
 
     def plan_info(self, name, description):
-        click.echo(
+        print(
             "*** WARNING: BITBAKE SUPPORT IS EXPERIMENTAL ***\n"
             "Running Bake plan '{}': '{}'".format(name, description)
         )
@@ -229,7 +228,7 @@ class BakePlan(PlanType):
 
         # handling manifest
         if data.get("local_manifest", None):
-            local_manifest = click.format_filename(data["local_manifest"])
+            local_manifest = data["local_manifest"]
             (manifest_file, manifest_content) = build.handle_manifest(local_manifest)
             req_data["manifests"] = {manifest_file: manifest_content}
 
