@@ -1,8 +1,6 @@
 # -*- coding: utf-8 -*-
 
 from attr import attrs, attrib
-from tuxsuite.cli.argparse import setup_parser
-from tuxsuite.cli.config import load_config
 
 
 class defaults:
@@ -60,9 +58,3 @@ result_states = {
         cli_color="cyan",
     ),
 }
-
-
-def tuxcli_load():
-    cfg = load_config()
-    options = setup_parser(cfg.group, cfg.project).parse_args()
-    return (cfg, options)
